pub enum ValidatorField {
WithdrawalCredentials,
EffectiveBalance,
Slashed,
ActivationEligibilityEpoch,
ActivationEpoch,
ExitEpoch,
WithdrawableEpochSlashed,
}Expand description
A field-level modification to a validator record.
Validator fields are diffed independently to avoid rewriting entire 121-byte SSZ validator records when only a small subset of fields change.
Variants
WithdrawalCredentials
EffectiveBalance
Slashed
ActivationEligibilityEpoch
ActivationEpoch
ExitEpoch
WithdrawableEpochSlashed