pub struct ValidatorsDiff {
pub patches: Vec<ValidatorPatch>,
pub appended_validators: Vec<u8>,
}Expand description
Compact representation of the difference between two validator registries.
Only modified validator fields are recorded. Newly appended validators are stored as raw SSZ bytes and appended during reconstruction.
Fields
patches: Vec<ValidatorPatch>appended_validators: Vec<u8>Trait Implementations
Sourceimpl Archive for ValidatorsDiff
impl Archive for ValidatorsDiff
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedValidatorsDiff
type Archived = ArchivedValidatorsDiff
The archived representation of this type. Read more
Sourcetype Resolver = ValidatorsDiffResolver
type Resolver = ValidatorsDiffResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ValidatorsDiff
impl Clone for ValidatorsDiff
Sourcefn clone(&self) -> ValidatorsDiff
fn clone(&self) -> ValidatorsDiff
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidatorsDiff
impl Debug for ValidatorsDiff
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ValidatorsDiff, __D> for Archived<ValidatorsDiff>where
Vec<ValidatorPatch>: Archive,
<Vec<ValidatorPatch> as Archive>::Archived: Deserialize<Vec<ValidatorPatch>, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ValidatorsDiff, __D> for Archived<ValidatorsDiff>where
Vec<ValidatorPatch>: Archive,
<Vec<ValidatorPatch> as Archive>::Archived: Deserialize<Vec<ValidatorPatch>, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ValidatorsDiff, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ValidatorsDiff, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for ValidatorsDiff
Sourceimpl PartialEq for ValidatorsDiff
impl PartialEq for ValidatorsDiff
impl StructuralPartialEq for ValidatorsDiff