pub fn apply<M: DiffTarget>(state: M, delta: &ArchivedBeaconStateDelta) -> MExpand description
Applies a previously created beacon-state delta.
The supplied DiffTarget is modified in place by applying each component
delta to reconstruct the target state.
The state’s fork must match the fork recorded in the delta.
Panics
Panics if the delta was created for a different consensus fork.
Complexity
Linear in the size of the recorded delta.