pub fn apply<M: DiffTarget>(
state: M,
delta: &ArchivedBeaconStateDelta,
) -> Result<M, Error>Expand description
Applies a previously created beacon-state delta.
The supplied DiffTarget is modified in place by applying each component
delta to reconstruct the target state.
The state’s fork must match the fork recorded in the delta.