create

Function create 

pub fn create<R: DiffSource>(state: &R) -> BeaconStateDelta
Creates a delta between two beacon states.

The supplied DiffSource provides access to the base and target state components required by each specialized encoder.

The returned BeaconStateDelta contains only the information necessary to reconstruct the target state from the base state.

Complexity

Linear in the size of the state components being compared.