Delta encoding for append-only historical logs.
Both historical_roots (Phase0 to Bellatrix) and historical_summaries
(Capella+) are append-only logs that grow by exactly one item per 8,192 slots.
This module uses protocol math to calculate exactly how many items were
appended, rather than comparing base and target byte arrays.
Functions
- apply_
historical_ log - Applies a historical log delta in place.
- diff_
historical_ log - Computes a historical log delta using protocol math.