diff_queue

Function diff_queue 

pub fn diff_queue(
    base_ssz: &[u8],
    target_ssz: &[u8],
    item_ssz_size: usize,
) -> QueueDiff
Computes the delta between two serialized queue lists.

Algorithm

  1. Locates the first item of the target queue within the base queue only at valid item boundaries.
  2. Strictly validates that the remaining items in the base queue are exactly identical to the prefix of the target queue.
  3. If valid, emits QueueDiff::Fifo. If invalid, emits QueueDiff::FullReplacement.