pub fn diff_queue(
base_ssz: &[u8],
target_ssz: &[u8],
item_ssz_size: usize,
) -> QueueDiffExpand description
Computes the delta between two serialized queue lists.
Algorithm
- Locates the first item of the target queue within the base queue only at valid item boundaries.
- Strictly validates that the remaining items in the base queue are exactly identical to the prefix of the target queue.
- If valid, emits
QueueDiff::Fifo. If invalid, emitsQueueDiff::FullReplacement.