pub struct BeaconStateDelta {Show 15 fields
pub fork: ForkName,
pub base_slot: u64,
pub scalar_header: Vec<u8>,
pub balances: BalancesDiff,
pub previous_participation: ParticipationDiff,
pub validators: ValidatorsDiff,
pub block_roots: RootsDiff,
pub state_roots: RootsDiff,
pub randao_mixes: RandaoDiff,
pub slashings: SlashingsDiff,
pub inactivity_scores: InactivityDiff,
pub eth1_data_votes: Eth1DataVotesDiff,
pub pending_deposits: FifoQueueDiff,
pub pending_partial_withdrawals: FifoQueueDiff,
pub pending_consolidations: FifoQueueDiff,
}Expand description
Complete delta describing the transition between two beacon states.
Each field uses a specialized encoding optimized for the corresponding consensus data structure.
A BeaconStateDelta can be serialized, persisted, transmitted, and later
applied to a compatible base state to reconstruct the target state.
Fields
fork: ForkNamebase_slot: u64scalar_header: Vec<u8>balances: BalancesDiffprevious_participation: ParticipationDiffvalidators: ValidatorsDiffblock_roots: RootsDiffstate_roots: RootsDiffrandao_mixes: RandaoDiffslashings: SlashingsDiffinactivity_scores: InactivityDiffeth1_data_votes: Eth1DataVotesDiffpending_deposits: FifoQueueDiffpending_partial_withdrawals: FifoQueueDiffpending_consolidations: FifoQueueDiffTrait Implementations
Sourceimpl Archive for BeaconStateDeltawhere
ForkName: Archive,
u64: Archive,
Vec<u8>: Archive,
BalancesDiff: Archive,
ParticipationDiff: Archive,
ValidatorsDiff: Archive,
RootsDiff: Archive,
RandaoDiff: Archive,
SlashingsDiff: Archive,
InactivityDiff: Archive,
Eth1DataVotesDiff: Archive,
FifoQueueDiff: Archive,
impl Archive for BeaconStateDeltawhere
ForkName: Archive,
u64: Archive,
Vec<u8>: Archive,
BalancesDiff: Archive,
ParticipationDiff: Archive,
ValidatorsDiff: Archive,
RootsDiff: Archive,
RandaoDiff: Archive,
SlashingsDiff: Archive,
InactivityDiff: Archive,
Eth1DataVotesDiff: Archive,
FifoQueueDiff: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedBeaconStateDelta
type Archived = ArchivedBeaconStateDelta
The archived representation of this type. Read more
Sourcetype Resolver = BeaconStateDeltaResolver
type Resolver = BeaconStateDeltaResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for BeaconStateDelta
impl Clone for BeaconStateDelta
Sourcefn clone(&self) -> BeaconStateDelta
fn clone(&self) -> BeaconStateDelta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BeaconStateDelta
impl Debug for BeaconStateDelta
Sourceimpl<__D: Fallible + ?Sized> Deserialize<BeaconStateDelta, __D> for Archived<BeaconStateDelta>where
ForkName: Archive,
<ForkName as Archive>::Archived: Deserialize<ForkName, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
BalancesDiff: Archive,
<BalancesDiff as Archive>::Archived: Deserialize<BalancesDiff, __D>,
ParticipationDiff: Archive,
<ParticipationDiff as Archive>::Archived: Deserialize<ParticipationDiff, __D>,
ValidatorsDiff: Archive,
<ValidatorsDiff as Archive>::Archived: Deserialize<ValidatorsDiff, __D>,
RootsDiff: Archive,
<RootsDiff as Archive>::Archived: Deserialize<RootsDiff, __D>,
RandaoDiff: Archive,
<RandaoDiff as Archive>::Archived: Deserialize<RandaoDiff, __D>,
SlashingsDiff: Archive,
<SlashingsDiff as Archive>::Archived: Deserialize<SlashingsDiff, __D>,
InactivityDiff: Archive,
<InactivityDiff as Archive>::Archived: Deserialize<InactivityDiff, __D>,
Eth1DataVotesDiff: Archive,
<Eth1DataVotesDiff as Archive>::Archived: Deserialize<Eth1DataVotesDiff, __D>,
FifoQueueDiff: Archive,
<FifoQueueDiff as Archive>::Archived: Deserialize<FifoQueueDiff, __D>,
impl<__D: Fallible + ?Sized> Deserialize<BeaconStateDelta, __D> for Archived<BeaconStateDelta>where
ForkName: Archive,
<ForkName as Archive>::Archived: Deserialize<ForkName, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
BalancesDiff: Archive,
<BalancesDiff as Archive>::Archived: Deserialize<BalancesDiff, __D>,
ParticipationDiff: Archive,
<ParticipationDiff as Archive>::Archived: Deserialize<ParticipationDiff, __D>,
ValidatorsDiff: Archive,
<ValidatorsDiff as Archive>::Archived: Deserialize<ValidatorsDiff, __D>,
RootsDiff: Archive,
<RootsDiff as Archive>::Archived: Deserialize<RootsDiff, __D>,
RandaoDiff: Archive,
<RandaoDiff as Archive>::Archived: Deserialize<RandaoDiff, __D>,
SlashingsDiff: Archive,
<SlashingsDiff as Archive>::Archived: Deserialize<SlashingsDiff, __D>,
InactivityDiff: Archive,
<InactivityDiff as Archive>::Archived: Deserialize<InactivityDiff, __D>,
Eth1DataVotesDiff: Archive,
<Eth1DataVotesDiff as Archive>::Archived: Deserialize<Eth1DataVotesDiff, __D>,
FifoQueueDiff: Archive,
<FifoQueueDiff as Archive>::Archived: Deserialize<FifoQueueDiff, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<BeaconStateDelta, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<BeaconStateDelta, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for BeaconStateDelta
Sourceimpl PartialEq for BeaconStateDelta
impl PartialEq for BeaconStateDelta
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for BeaconStateDeltawhere
ForkName: Serialize<__S>,
u64: Serialize<__S>,
Vec<u8>: Serialize<__S>,
BalancesDiff: Serialize<__S>,
ParticipationDiff: Serialize<__S>,
ValidatorsDiff: Serialize<__S>,
RootsDiff: Serialize<__S>,
RandaoDiff: Serialize<__S>,
SlashingsDiff: Serialize<__S>,
InactivityDiff: Serialize<__S>,
Eth1DataVotesDiff: Serialize<__S>,
FifoQueueDiff: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for BeaconStateDeltawhere
ForkName: Serialize<__S>,
u64: Serialize<__S>,
Vec<u8>: Serialize<__S>,
BalancesDiff: Serialize<__S>,
ParticipationDiff: Serialize<__S>,
ValidatorsDiff: Serialize<__S>,
RootsDiff: Serialize<__S>,
RandaoDiff: Serialize<__S>,
SlashingsDiff: Serialize<__S>,
InactivityDiff: Serialize<__S>,
Eth1DataVotesDiff: Serialize<__S>,
FifoQueueDiff: Serialize<__S>,
impl StructuralPartialEq for BeaconStateDelta