pub trait DiffTarget {
Show 14 methods
// Required methods
fn get_fork(&self) -> ForkName;
fn scalar_header_mut(&mut self) -> &mut Vec<u8> ⓘ;
fn balances_mut(&mut self) -> &mut Vec<u64>;
fn previous_participation_mut(&mut self) -> &mut Vec<u8> ⓘ;
fn validators_mut(&mut self) -> &mut Vec<u8> ⓘ;
fn block_roots_mut(&mut self) -> &mut [[u8; 32]];
fn state_roots_mut(&mut self) -> &mut [[u8; 32]];
fn randao_mixes_mut(&mut self) -> &mut [[u8; 32]];
fn slashings_mut(&mut self) -> &mut [u64];
fn inactivity_scores_mut(&mut self) -> &mut Vec<u64>;
fn eth1_data_votes_mut(&mut self) -> &mut Vec<u8> ⓘ;
fn pending_deposits_mut(&mut self) -> &mut Vec<u8> ⓘ;
fn pending_partial_withdrawals_mut(&mut self) -> &mut Vec<u8> ⓘ;
fn pending_consolidations_mut(&mut self) -> &mut Vec<u8> ⓘ;
}Expand description
Mutable view of a beacon state.
Implement this trait for your beacon-state representation to allow
apply to reconstruct a target state from a BeaconStateDelta.
The trait intentionally operates on primitive buffers and slices rather than client-specific types, allowing integration with any consensus client.
Required Methods
fn get_fork(&self) -> ForkName
fn scalar_header_mut(&mut self) -> &mut Vec<u8> ⓘ
fn balances_mut(&mut self) -> &mut Vec<u64>
fn previous_participation_mut(&mut self) -> &mut Vec<u8> ⓘ
fn validators_mut(&mut self) -> &mut Vec<u8> ⓘ
fn block_roots_mut(&mut self) -> &mut [[u8; 32]]
fn state_roots_mut(&mut self) -> &mut [[u8; 32]]
fn randao_mixes_mut(&mut self) -> &mut [[u8; 32]]
fn slashings_mut(&mut self) -> &mut [u64]
fn inactivity_scores_mut(&mut self) -> &mut Vec<u64>
fn eth1_data_votes_mut(&mut self) -> &mut Vec<u8> ⓘ
fn pending_deposits_mut(&mut self) -> &mut Vec<u8> ⓘ
fn pending_partial_withdrawals_mut(&mut self) -> &mut Vec<u8> ⓘ
fn pending_consolidations_mut(&mut self) -> &mut Vec<u8> ⓘ
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".