pub struct BalancesDiff {
pub tags: BitTagVec,
pub mode: i64,
pub varint_payload: Vec<u8>,
pub target_values: Vec<u64>,
pub appended_balances: Vec<u64>,
}Expand description
Compact representation of the difference between two balance snapshots.
A BalanceDiffs stores only the information required to transform one
balance vector into another.
Small balance differences are encoded as mode-adjusted zig-zag varints, while values that can not be represented efficiently are stored explicitly.
This structure is intended to be serialized with rkyv.
Fields
mode: i64varint_payload: Vec<u8>target_values: Vec<u64>appended_balances: Vec<u64>Trait Implementations
Sourceimpl Archive for BalancesDiff
impl Archive for BalancesDiff
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedBalancesDiff
type Archived = ArchivedBalancesDiff
The archived representation of this type. Read more
Sourcetype Resolver = BalancesDiffResolver
type Resolver = BalancesDiffResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for BalancesDiff
impl Clone for BalancesDiff
Sourcefn clone(&self) -> BalancesDiff
fn clone(&self) -> BalancesDiff
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BalancesDiff
impl Debug for BalancesDiff
Sourceimpl<__D: Fallible + ?Sized> Deserialize<BalancesDiff, __D> for Archived<BalancesDiff>where
BitTagVec: Archive,
<BitTagVec as Archive>::Archived: Deserialize<BitTagVec, __D>,
i64: Archive,
<i64 as Archive>::Archived: Deserialize<i64, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
Vec<u64>: Archive,
<Vec<u64> as Archive>::Archived: Deserialize<Vec<u64>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<BalancesDiff, __D> for Archived<BalancesDiff>where
BitTagVec: Archive,
<BitTagVec as Archive>::Archived: Deserialize<BitTagVec, __D>,
i64: Archive,
<i64 as Archive>::Archived: Deserialize<i64, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
Vec<u64>: Archive,
<Vec<u64> as Archive>::Archived: Deserialize<Vec<u64>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<BalancesDiff, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<BalancesDiff, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for BalancesDiff
Sourceimpl PartialEq for BalancesDiff
impl PartialEq for BalancesDiff
impl StructuralPartialEq for BalancesDiff